from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.cloudformation.checks.resource.base_resource_value_check import BaseResourceValueCheck


class ElasticacheReplicationGroupEncryptionAtRest(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure all data stored in the Elasticache Replication Group is securely encrypted at rest"
        id = "CKV_AWS_29"
        supported_resources = ['AWS::ElastiCache::ReplicationGroup']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return 'Properties/AtRestEncryptionEnabled'

check = ElasticacheReplicationGroupEncryptionAtRest()



import logging
from checkov.terraform.context_parsers.tf_plan.node import dict_node

try:
    from json.decoder import JSONDecodeError
except ImportError:
    JSONDecodeError = ValueError

from checkov.terraform.context_parsers.tf_plan import tf_plan_json

LOGGER = logging.getLogger(__name__)


def parse(filename):
    """
        Decode filename into an object
    """
    template = None
    template_lines = None
    try:
        (template, template_lines) = tf_plan_json.load(filename)
    except tf_plan_json.JSONDecodeError:
        pass

    if template is not None and isinstance(template, dict_node) and 'terraform_version' in template and 'planned_values' in template:
        return template, template_lines
    return None, None



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class ECSTaskDefinitionEFSVolumeEncryption(BaseResourceCheck):
    def __init__(self):
        name = "Ensure Encryption in transit is enabled for ECS Task defintion EFS volumes"
        id = "CKV_AWS_97"
        supported_resources = ['aws_ecs_task_definition']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if 'volume' in conf.keys():
            volume_conf = conf['volume']
            for volume in volume_conf:
                if isinstance(volume, dict) and 'efs_volume_configuration' in volume:
                    efs_conf = volume['efs_volume_configuration']
                    for efs in efs_conf:
                        if isinstance(efs, dict):
                            if 'transit_encryption' in efs and efs['transit_encryption'] == ['ENABLED']:
                                return CheckResult.PASSED
                            else:
                                return CheckResult.FAILED
        return CheckResult.PASSED


check = ECSTaskDefinitionEFSVolumeEncryption()



from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
from checkov.common.models.enums import CheckResult, CheckCategories


class GoogleCloudDNSKeySpecsRSASHA1(BaseResourceCheck):
    def __init__(self):
        name = "Ensure that RSASHA1 is not used for the zone-signing and key-signing keys in Cloud DNS DNSSEC"
        id = "CKV_GCP_17"
        supported_resources = ["google_dns_managed_zone"]
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        """
            Looks for DNSSEC key algorithm at dns_managed_zone:
            https://www.terraform.io/docs/providers/google/r/dns_managed_zone.html#algorithm
        :param conf: dns_managed_zone configuration
        :return: <CheckResult>
        """
        if "dnssec_config" in conf.keys():
            dnssec_config = conf["dnssec_config"][0]

            # default algo RSASHA256 as per the documentation:
            # https://cloud.google.com/dns/docs/dnssec-advanced#advanced-signing-options
            if "default_key_specs" in dnssec_config:
                for default_key_specs in dnssec_config["default_key_specs"]:
                    if "algorithm" in default_key_specs and default_key_specs["algorithm"] == ["rsasha1"]:
                        return CheckResult.FAILED

        return CheckResult.PASSED


check = GoogleCloudDNSKeySpecsRSASHA1()
